getWeilbull: Estimate parameters of the Weibull survival distributions for each subgroup.
Description
Estimate parameters of the Weibull survival distributions for each subgroup.
Usage
getWeilbull(dat)
Value
shape and scale parameters of the Weibull distribution for each subgroup.
Arguments
dat
- data frame of three columns: 1) time: follow up time; 2) status: indicator, 0=no event, 1=event; 3) group, integer 1,...,n, for each subgroup of patients.
References
Hong Zhang, Jie Pu, Shibing Deng, Satrajit Roychoudhury, Haitao Chu and Douglas Robinson. "Study Duration Prediction for Clinical Trials with Time-to-Event Endpoints Using Mixture Distributions Accounting for Heterogeneous Population", arXiv:2401.00540.